Changelog
=========

Version 1.0.0 (2017-06-08)
--------------------------

* Initial release

Version 0.2 (2017-10-14)
------------------------

* For NIST TE Challenge 2

Version 0.1.4 (2018-09-30)
--------------------------

* For GridAPPS-D Demo
* GridLAB-D feature/1146 branch with FNCS-controlled switching

Version 0.1.9 (2018-12-13)
--------------------------

* Three desktop version installers for Mac, Windows and Linux
* Tutorial video
* DSO+T study files





